==> jwinner-base-0.0.3-sources.jar: itez/plat/base/model/base/BaseDept.java <==
package itez.plat.base.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BaseDept<M extends BaseDept<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setPid(java.lang.String pid) {
		set("pid", pid);
		return (M)this;
	}
	
	public java.lang.String getPid() {
		return getStr("pid");
	}

	public M setCompId(java.lang.String compId) {
		set("compId", compId);
		return (M)this;
	}
	
	public java.lang.String getCompId() {
		return getStr("compId");
	}

	public M setCaption(java.lang.String caption) {
		set("caption", caption);
		return (M)this;
	}
	
	public java.lang.String getCaption() {
		return getStr("caption");
	}

	public M setSummary(java.lang.String summary) {
		set("summary", summary);
		return (M)this;
	}
	
	public java.lang.String getSummary() {
		return getStr("summary");
	}

	public M setLevel(java.lang.Integer level) {
		set("level", level);
		return (M)this;
	}
	
	public java.lang.Integer getLevel() {
		return getInt("level");
	}

	public M setPath(java.lang.String path) {
		set("path", path);
		return (M)this;
	}
	
	public java.lang.String getPath() {
		return getStr("path");
	}

	public M setTmid(java.lang.String tmid) {
		set("tmid", tmid);
		return (M)this;
	}
	
	public java.lang.String getTmid() {
		return getStr("tmid");
	}

	public M setSort(java.lang.Integer sort) {
		set("sort", sort);
		return (M)this;
	}
	
	public java.lang.Integer getSort() {
		return getInt("sort");
	}

	public M setUsed(java.lang.Integer used) {
		set("used", used);
		return (M)this;
	}
	
	public java.lang.Integer getUsed() {
		return getInt("used");
	}

}

==> jwinner-base-0.0.6-sources.jar: itez/plat/base/model/base/BaseDept.java <==
package itez.plat.base.model.base;

import itez.core.wrapper.dbo.model.EModel;
import com.jfinal.plugin.activerecord.IBean;

/**
 * 由JWinner Model Generator自动生成，请勿修改本文件。
 */
@SuppressWarnings({"serial", "unchecked"})
public abstract class BaseDept<M extends BaseDept<M>> extends EModel<M> implements IBean {

	public M setId(java.lang.String id) {
		set("id", id);
		return (M)this;
	}
	
	public java.lang.String getId() {
		return getStr("id");
	}

	public M setPid(java.lang.String pid) {
		set("pid", pid);
		return (M)this;
	}
	
	public java.lang.String getPid() {
		return getStr("pid");
	}

	public M setNum(java.lang.String num) {
		set("num", num);
		return (M)this;
	}
	
	public java.lang.String getNum() {
		return getStr("num");
	}

	public M setCompId(java.lang.String compId) {
		set("compId", compId);
		return (M)this;
	}
	
	public java.lang.String getCompId() {
		return getStr("compId");
	}

	public M setCaption(java.lang.String caption) {
		set("caption", caption);
		return (M)this;
	}
	
	public java.lang.String getCaption() {
		return getStr("caption");
	}

	public M setSummary(java.lang.String summary) {
		set("summary", summary);
		return (M)this;
	}
	
	public java.lang.String getSummary() {
		return getStr("summary");
	}

	public M setLevel(java.lang.Integer level) {
		set("level", level);
		return (M)this;
	}
	
	public java.lang.Integer getLevel() {
		return getInt("level");
	}

	public M setPath(java.lang.String path) {
		set("path", path);
		return (M)this;
	}
	
	public java.lang.String getPath() {
		return getStr("path");
	}

	public M setHide(java.lang.Integer hide) {
		set("hide", hide);
		return (M)this;
	}
	
	public java.lang.Integer getHide() {
		return getInt("hide");
	}

	public M setTmid(java.lang.String tmid) {
		set("tmid", tmid);
		return (M)this;
	}
	
	public java.lang.String getTmid() {
		return getStr("tmid");
	}

	public M setSort(java.lang.Integer sort) {
		set("sort", sort);
		return (M)this;
	}
	
	public java.lang.Integer getSort() {
		return getInt("sort");
	}

	public M setUsed(java.lang.Integer used) {
		set("used", used);
		return (M)this;
	}
	
	public java.lang.Integer getUsed() {
		return getInt("used");
	}

}
